@@ -44,9 +44,9 @@ impl MimeData {
 /// to a list of handlers, and [`FileResourceHandler`] for a resource handler for
 /// local files.
 ///
-/// For remote URLs, see e.g. [mdcat-http-reqwest](https://docs.rs/mdcat-http-reqwest)
-/// for an implementation which fetches HTTP resources with the `reqwest` library.
-pub trait ResourceUrlHandler: Send + Sync + Debug {
+/// For remote URLs implement this handler on top of a suitable crate for network
+/// requests, e.q. [`reqwest`](https://docs.rs/reqwest) or [`curl`](https://docs.rs/curl).
+pub trait ResourceUrlHandler {
     /// Read a resource.
     ///
     /// Read data from the given `url`, and return the data and its associated mime type if known,
@@ -80,7 +80,6 @@ pub fn filter_schemes<'a>(schemes: &[&str], url: &'a Url) -> Result<&'a Url> {
 }
 
 /// A resource handler which dispatches reading among a list of inner handlers.
-#[derive(Debug)]
 pub struct DispatchingResourceHandler {
     /// Inner handlers.
     handlers: Vec<Box<dyn ResourceUrlHandler>>,
